function [delta_s,delta_l] = delta_suggested(stdcan,lb,ub,obj_data)
    type = obj_data.func_type;
    coeffs = obj_data.coeffs;
    exponent = obj_data.exponent;
    pos_idx = obj_data.pos_idx;
    neg_idx = obj_data.neg_idx;
    indexes = obj_data.indexes;
    coeffs_matrix = obj_data.coeffs_matrix;
    coeffs_exp = obj_data.coeffs_exp;
    
    switch type
        case 1
            [min,max] = minmax(coeffs);
            delta_s = min;
            delta_l = max;
        case 2
            [min,max] = minmax(coeffs);
            if exponent == 1
                delta_s = min;
                delta_l = max;
            else
                if ~stdcan
                    temp = lb;
                    lb = ub;
                    ub = temp;
                end
                if exponent > 0 && exponent < 1
                    delta_s = min*abs(exponent)*(coeffs*ub')^(exponent-1);
                    delta_l = max*abs(exponent)*(coeffs*lb')^(exponent-1);
                else
                    delta_s = min*abs(exponent)*(coeffs*lb')^(exponent-1);
                    delta_l = max*abs(exponent)*(coeffs*ub')^(exponent-1);
                end
            end
        case 3
            if isempty(pos_idx) && isempty(neg_idx);
                [min,max] = minmax(coeffs);
                delta_s = min;
                delta_l = max;
            else
                [min,max] = minmax_quadratic(coeffs,pos_idx,neg_idx,lb,ub);
                delta_s = min;
                delta_l = max;
            end
        case 4
            if exponent == 1
                if isempty(indexes);
                    [min,max] = minmax(coeffs);
                    delta_s = min;
                    delta_l = max;
                else
                    [min,max] = minmax_quadratic(coeffs,pos_idx,neg_idx,lb,ub);
                    delta_s = min;
                    delta_l = max;
                end
            else
                if ~stdcan
                    temp = lb;
                    lb = ub;
                    ub = temp;
                end
                if isempty(indexes)
                    [min,max] = minmax(coeffs);
                    if exponent > 0 && exponent < 1
                        delta_s = min*abs(exponent)*(coeffs*ub')^(exponent-1);
                        delta_l = max*abs(exponent)*(coeffs*lb')^(exponent-1);
                    else
                        delta_s = min*abs(exponent)*(coeffs*lb')^(exponent-1);
                        delta_l = max*abs(exponent)*(coeffs*ub')^(exponent-1);
                    end
                else
                    [delta_s,delta_l] = minmax_quadratic_exp(coeffs,indexes,exponent,lb,ub);
                end
            end
        case 5
            min = Inf;
            max = 0;
            n = length(coeffs_matrix);
            posneg = 1;
            if isempty(pos_idx), posneg = 0; end
            for i = 1:n,
                min_val = 0;
                max_val = 0;
                for j = 1:n,
                    a = 0;
                    if j == i
                        a = 2*coeffs_matrix(i,i);
                    else
                        a = coeffs_matrix(i,j) + coeffs_matrix(j,i);
                    end
                    if posneg
                        min_val = min_val + abs(a*lb(j));
                        max_val = max_val + abs(a*ub(j));
                    else
                        min_val = min_val + abs(a*ub(j));
                        max_val = max_val + abs(a*lb(j));
                    end
                end
                if min_val < min; min = min_val; end
                if max_val > max; max = max_val; end
            end
            delta_s = min;
            delta_l = max;
        case 6
            min = Inf;
            max = 0;
            n = length(coeffs);
            for i = 1:n,
                min_val = abs(coeffs(i)*coeffs_exp(i)*exp(coeffs_exp(i)*lb(i)));
                max_val = abs(coeffs(i)*coeffs_exp(i)*exp(coeffs_exp(i)*ub(i)));
                if min_val < max_val
                    if min_val < min, min = min_val; end
                    if max_val > max, max = max_val; end
                else
                    if max_val < min, min = max_val; end
                    if min_val > max, max = min_val; end
                end
            end
            delta_s = min;
            delta_l = max;
    end
            
    
    function [min,max] = minmax(coeffs)
        min = Inf;
        max = 0;
        n = length(coeffs);
        for i = 1:n,
            if (abs(coeffs(i)) < min), min = abs(coeffs(i)); end
            if (abs(coeffs(i)) > max), max = abs(coeffs(i)); end
        end 
    end

    function [min,max] = minmax_quadratic(coeffs,pos_idx,neg_idx,lb,ub)
        min = Inf;
        max = 0;
        n = length(coeffs);
        pos_counter = 1;
        neg_counter = 1;

        for i = 1:n,
            if ~isempty(pos_idx) && pos_idx(pos_counter) == i
                min_value = 2*abs(coeffs(i)*lb(i));
                max_value = 2*abs(coeffs(i)*ub(i));
                if (min_value < min), min = min_value; end
                if (max_value > max), max = max_value; end
                if pos_counter < length(pos_idx), pos_counter = pos_counter + 1; end
            elseif ~isempty(neg_idx) && neg_idx(neg_counter) == i
                min_value = 2*abs(coeffs(i)*ub(i));
                max_value = 2*abs(coeffs(i)*lb(i));
                if (min_value < min), min = min_value; end
                if (max_value > max), max = max_value; end
                if neg_counter < length(neg_idx), neg_counter = neg_counter + 1; end
            else
                if (abs(coeffs(i)) < min), min = abs(coeffs(i)); end
                if (abs(coeffs(i)) > max), max = abs(coeffs(i)); end
            end
        end 
    end

    function [delta_s,delta_l] = minmax_quadratic_exp(coeffs,indexes,k,lb,ub)
        min = Inf;
        max = 0;
        base_min = 0;
        base_max = 0;
        n = length(coeffs);
        counter = 1;

        for i = 1:n,
            if ~isempty(indexes) && indexes(counter) == i
                if k > 0
                    min_value = 2*abs(coeffs(i)*lb(i)*k);
                    max_value = 2*abs(coeffs(i)*ub(i)*k);
                else
                    min_value = 2*abs(coeffs(i)*ub(i)*k);
                    max_value = 2*abs(coeffs(i)*lb(i)*k);
                end
                if (min_value < min), min = min_value; end
                if (max_value > max), max = max_value; end
                
                if k < 1 && k > 0
                    base_min = base_min + coeffs(i)*ub(i)^2;
                    base_max = base_max + coeffs(i)*lb(i)^2;
                else
                    base_min = base_min + coeffs(i)*lb(i)^2;
                    base_max = base_max + coeffs(i)*ub(i)^2;
                end
                if counter < length(indexes), counter = counter + 1; end
            else
                if (abs(coeffs(i)*k) < min), min = abs(coeffs(i)*k); end
                if (abs(coeffs(i)*k) > max), max = abs(coeffs(i)*k); end
                
                if k < 1 && k > 0
                    base_min = base_min + coeffs(i)*ub(i);
                    base_max = base_max + coeffs(i)*lb(i);
                else
                    base_min = base_min + coeffs(i)*lb(i);
                    base_max = base_max + coeffs(i)*ub(i);
                end
            end
        end
        
        delta_s = min*base_min^(k-1);
        delta_l = max*base_max^(k-1);
    end
end