function [f_lip,msg,tot_itr,func_count] = isflip_canonical(handle_nabla_g_0,handle_nabla_G,m,n,lb,ub,data_adv,obj_data)
    inputerr = 0;
    if nargin == 8
        adv = 1;
        custom = 0;
    elseif nargin == 7
        adv = 1;
        custom = 1;
    elseif nargin < 6
        inputerr = 1;
    else
        adv = 0;
        custom = 1;
    end
    
    f_lip = 0;
    error = 0;
    tot_itr = 0;
    fmin_itr = 0;
    func_count = 0;
    
    if ~inputerr
        checked3c = 0;
        delta_s = -1;
        delta_l = -1;

        options = optimset('Algorithm','active-set');
        alt_options = optimset('Algorithm','interior-point');

        try
        % Check if objective function is strictly decreasing
        if custom
            if adv && data_adv.obj_strict
                xm = lb + (ub - lb)./2;
                val = feval(handle_nabla_g_0,xm);
                if isnan(val(1,1))
                    error = 1;
                    msg = 'Error: the objective gradient is not defined everywhere.';
                elseif val(1,1) > 0
                    error = 1;
                    msg = '-The objective function is not strictly decreasing.';
                elseif val == 0
                    error = 1;
                    msg = 'Error: Incorrect information, the objective function is not strictly decreasing.';
                end
            elseif adv && data_adv.obj_grad
                f_min = -feval(handle_nabla_g_0,lb);
                f_max = -feval(handle_nabla_g_0,ub);
                min = Inf;
                max = 0;
                for i = 1:m,
                    for j = 1:n,
                        tot_itr = tot_itr + 1;
                        if min > f_min(i,j); min = f_min(i,j); end
                        if min > f_max(i,j); min = f_max(i,j); end
                        if max < f_min(i,j); max = f_min(i,j); end
                        if max < f_max(i,j); max = f_max(i,j); end

                        if isnan(f_min(i,j)) || isnan(f_max(i,j))
                            error = 1;
                            msg = 'Error: the objective gradient is not defined everywhere.';
                            break;
                        elseif f_min(i,j) <= 0 || f_max(i,j) <= 0
                            error = 1;
                            msg = '-The objective function is not strictly decreasing.';
                            break;
                        end
                    end
                    if error, break; end
                end
                delta_s = min;
                delta_l = max;
            else
                min = Inf;
                for i = 1:m,
                    for j = 1:n,
                        x0 = lb;
                        if (lb(1,j) == 0)
                            x0 = ub;
                        end
                        fmincon_err = 0;
                        try
                            [T, ~, fval, ~, output] = evalc('fmincon(@(x) -func_ij(handle_nabla_g_0,x,i,j), x0, [], [], [], [], lb, ub, [], options)');
                        catch exception
                            fmincon_err = 1;
                        end

                        if ~fmincon_err, fmincon_err = ~sol_found(T); end
                        if fmincon_err
                            fmincon_err = 0;
                            try
                                [T, ~, fval, ~, output] = evalc('fmincon(@(x) -func_ij(handle_nabla_g_0,x,i,j), x0, [], [], [], [], lb, ub, [], alt_options)');
                            catch exception
                                fmincon_err = 1;
                            end
                        end

                        if ~fmincon_err, fmincon_err = ~sol_found(T); end
                        if ~fmincon_err
                            if output.iterations ~= 0
                                fmin_itr = fmin_itr + output.iterations;
                            else
                                fmin_itr = fmin_itr + 1;
                            end
                            func_count = func_count + output.funcCount;
                            if (m == 1 && fval < min), min = fval; end
                            if (fval <= 0)
                                error = 1;
                                msg = '-The objective function is not strictly decreasing.';
                                break;
                            end
                        else
                            error = 1;
                            msg = 'Error: fmincon caught internal exception. The problem cannot be verified.';
                            break;
                        end
                    end
                    if (error), break; end
                end
                delta_s = min;
            end
        else
            % Check if the bounds fulfill potential requirements
            if ~isempty(obj_data.neg_idx)
                for i = 1:length(obj_data.neg_idx),
                    if ub(obj_data.neg_idx(i)) >= 0
                        error = 1;
                        msg1 = 'Error: In order to have a strictly increasing objective function, the following terms of x must be bounded to only negative numbers:';
                        msg2 = idx2str(obj_data.neg_idx);
                        msg = strcat(msg1,msg2);
                        break;
                    end
                end
            elseif ~isempty(obj_data.pos_idx)
                for i = 1:length(obj_data.pos_idx),
                    if lb(obj_data.pos_idx(i)) <= 0
                        error = 1;
                        msg1 = 'Error: In order to have a strictly increasing objective function, the following terms of x must be bounded to only positive numbers:';
                        msg2 = idx2str(obj_data.pos_idx);
                        msg = strcat(msg1,msg2);
                        break;
                    end
                end
            end
        end


        % Check if diagonal is positive
        if (~error)
            msg = sprintf('-The objective function is strictly decreasing.');
            if adv && data_adv.constr_grad
                f_min = feval(handle_nabla_G,lb);
                f_max = feval(handle_nabla_G,ub);
                for i = 1:n,
                    tot_itr = tot_itr + 1;

                    if isnan(f_min(i,i)) || isnan(f_max(i,i))
                        error = 1;
                        msg = 'Error: The constraint gradient is not defined everywhere.';
                        break;
                    elseif  f_min(i,i) <= 0 || f_max(i,i) <= 0
                        error = 1;
                        msg1 = sprintf('\n-The diagonal of the constraint gradient is not strictly positive.');
                        msg = strcat(msg,msg1);
                        break;
                    end
                end
            else
                for i = 1:n,
                    x0 = lb;
                    if (lb(1,i) == 0)
                        x0 = ub;
                    end
                    fmincon_err = 0;
                    try
                        [T, ~, fval, ~, output] = evalc('fmincon(@(x) func_ij(handle_nabla_G,x,i,i), x0, [], [], [], [], lb, ub, [], options)');
                    catch exception
                        fmincon_err = 1;
                    end

                    if ~fmincon_err, fmincon_err = ~sol_found(T); end
                    if fmincon_err
                        fmincon_err = 0;
                        try
                            [T, ~, fval, ~, output] = evalc('fmincon(@(x) func_ij(handle_nabla_G,x,i,i), x0, [], [], [], [], lb, ub, [], alt_options)');
                        catch exception
                            fmincon_err = 1;
                        end
                    end

                    if ~fmincon_err, fmincon_err = ~sol_found(T); end
                    if ~fmincon_err
                        if output.iterations ~= 0
                            fmin_itr = fmin_itr + output.iterations;
                        else
                            fmin_itr = fmin_itr + 1;
                        end
                        func_count = func_count + output.funcCount;
                        if (fval <= 0)
                            error = 1;
                            msg1 = sprintf('\n-The diagonal of the constraint gradient is not strictly positive.');
                            msg = strcat(msg,msg1);
                            break;
                        end
                    else
                        error = 1;
                        msg = 'Error: fmincon caught internal exception. The problem cannot be verified.';
                        break;
                    end
                end
            end
        end


        % Check if all off-diagonal elements are negative and if diagonal is
        % dominant
        if (~error)
            msg1 = sprintf('\n-The diagonal of the constraint gradient is strictly positive.');
            msg = strcat(msg,msg1,sprintf('\n\nAlternatives:'));
            valid = 1;

            if adv && data_adv.constr
                valid = 0;
                msg = strcat(msg,sprintf('\n1. -The off-diagonal elements of the constraint gradient are not all negative.'));
            elseif adv && data_adv.constr_grad
                f_min = feval(handle_nabla_G,lb);
                f_max = feval(handle_nabla_G,ub);
                for i = 1:n,
                    for j = 1:n,
                        if j ~= i
                            tot_itr = tot_itr + 1;
                            if isnan(f_min(i,j)) || isnan(f_max(i,j))
                                error = 1;
                                valid = 0;
                                msg = 'Error: The constraint gradient is not defined everywhere.';
                                break;
                            elseif f_min(i,j) > 0 || f_max(i,j) > 0
                                valid = 0;
                                msg = strcat(msg,sprintf('\n1. -The off-diagonal elements of the constraint gradient are not all negative.'));
                                break;
                            end
                        end
                    end
                    if ~valid, break; end
                end
            else
                for i = 1:n,
                    for j = 1:n,
                        if (j ~= i)
                            x0 = lb;
                            if (lb(1,j) == 0)
                                x0 = ub;
                            end
                            fmincon_err = 0;
                            try
                                [T, ~, fval, ~, output] = evalc('fmincon(@(x) -func_ij(handle_nabla_G,x,i,j), x0, [], [], [], [], lb, ub, [], options)');
                            catch exception
                                fmincon_err = 1;
                            end

                            if ~fmincon_err, fmincon_err = ~sol_found(T); end
                            if fmincon_err
                                fmincon_err = 0;
                                try
                                    [T, ~, fval, ~, output] = evalc('fmincon(@(x) -func_ij(handle_nabla_G,x,i,j), x0, [], [], [], [], lb, ub, [], alt_options)');
                                catch exception
                                    fmincon_err = 1;
                                end
                            end

                            if ~fmincon_err, fmincon_err = ~sol_found(T); end
                            if ~fmincon_err
                                if output.iterations ~= 0
                                    fmin_itr = fmin_itr + output.iterations;
                                else
                                    fmin_itr = fmin_itr + 1;
                                end
                                func_count = func_count + output.funcCount;
                                if (fval < 0)
                                    valid = 0;
                                    msg = strcat(msg,sprintf('\n1. -The off-diagonal elements of the constraint gradient are not all negative.'));
                                    break;
                                end
                            else
                                error = 1;
                                valid = 0;
                                msg = 'Error: fmincon caught internal exception. The problem cannot be verified.';
                                break;
                            end
                        end
                    end
                    if ~valid, break, end
                end
            end

            if (valid)
                msg = strcat(msg,sprintf('\n1. -The off-diagonal elements of the constraint gradient are all negative.'));
                if adv && data_adv.constr_grad
                    f_min = feval(handle_nabla_G,lb);
                    f_max = feval(handle_nabla_G,ub);
                    for i = 1:n,
                        tot_itr = tot_itr + 1;
                        sum_min = abs(f_min(i,:))*ones(n,1);
                        sum_max = abs(f_max(i,:))*ones(n,1);

                        if 2*f_min(i,i) <= sum_min || 2*f_max(i,i) <= sum_max
                            valid = 0;
                            msg1 = sprintf('\n    -The diagonal of the constraint gradient is not dominant.');
                            msg = strcat(msg,msg1);
                            break;
                        end
                    end
                else
                    for i = 1:n,
                        x0 = lb;
                        if (lb(1,i) == 0)
                            x0 = ub;
                        end
                        fmincon_err = 0;
                        try
                            [T, ~, fval, ~, output] = evalc('fmincon(@(x) diagonal1_nabla_G(handle_nabla_G,x,i,n), x0, [], [], [], [], lb, ub, [], options)');
                        catch exception
                            fmincon_err = 1;
                        end

                        if ~fmincon_err, fmincon_err = ~sol_found(T); end
                        if fmincon_err
                            fmincon_err = 0;
                            try
                                [T, ~, fval, ~, output] = evalc('fmincon(@(x) diagonal1_nabla_G(handle_nabla_G,x,i,n), x0, [], [], [], [], lb, ub, [], alt_options)');
                            catch exception
                                fmincon_err = 1;
                            end
                        end

                        if ~fmincon_err, fmincon_err = ~sol_found(T); end
                        if ~fmincon_err
                            if output.iterations ~= 0
                                fmin_itr = fmin_itr + output.iterations;
                            else
                                fmin_itr = fmin_itr + 1;
                            end
                            func_count = func_count + output.funcCount;
                            if (fval <= 0)
                                valid = 0;
                                msg1 = sprintf('\n    -The diagonal of the constraint gradient is not dominant.');
                                msg = strcat(msg,msg1);
                            end
                        else
                            error = 1;
                            valid = 0;
                            msg = 'Error: fmincon caught internal exception. The problem cannot be verified.';
                            break;
                        end
                    end
                end
            end

            if (valid)
                f_lip = 1;
                msg = strcat(msg,sprintf('\n    -The diagonal of the constraint gradient is dominant.'));
            end
        end

        % Check if nabla_j_g_0 = nabla_i_g_0 and if all off-diagonal elements
        % are positive.
        if (~error && ~f_lip && m == 1)
            valid = 1;
            if custom
                eval = zeros(1,6);
                eval_comp = zeros(1,6);
                for i = 1:6,
                    vals = lb + ((ub-lb)/5).*(i-1);
                    eval(i) = func_ij(handle_nabla_g_0,vals,1,1);
                end
                if eval*ones(6,1) == eval(1)*6;
                    for i = 2:n,
                        tot_itr = tot_itr + 1;
                        for j = 1:6,
                            vals = lb + ((ub-lb)/5).*(i-1);
                            eval_comp(j) = func_ij(handle_nabla_g_0,vals,1,i);
                        end
                        if ~isequal(eval,eval_comp)
                            valid = 0;
                            msg = strcat(msg,sprintf('\n2. -The gradients of the objective are not equal.'));
                            break;
                        end
                    end
                else
                    valid = 0;
                    msg = strcat(msg,sprintf('\n2. -The gradients of the objective are not equal.'));
                end
            else
                valid = (obj_data.func_type == 1) && obj_data.uniform;
                if ~valid, msg = strcat(msg,sprintf('\n2. -The gradients of the objective are not equal.')); end
            end

            if (valid)
                msg = strcat(msg,sprintf('\n2. -The gradients of the objective are equal.'));

                if adv && data_adv.constr
                    xm = lb + (ub - lb)./2;
                    f_m = feval(handle_nabla_G,xm);
                    if f_m(1,2) < 0
                        valid = 0;
                        msg = strcat(msg,sprintf('\n    -The off-diagonal elements of the constraint gradient are not all positive.'));
                    end
                elseif adv && data_adv.constr_grad
                    f_min = feval(handle_nabla_G,lb);
                    f_max = feval(handle_nabla_G,ub);
                    for i = 1:n,
                        for j = 1:n,
                            if j ~= i
                                tot_itr = tot_itr + 1;
                                if isnan(f_min(i,j)) || isnan(f_max(i,j))
                                    error = 1;
                                    valid = 0;
                                    msg = 'Error: The constraint gradient is not defined everywhere.';
                                    break;
                                elseif f_min(i,j) < 0 || f_max(i,j) < 0
                                    valid = 0;
                                    msg = strcat(msg,sprintf('\n    -The off-diagonal elements of the constraint gradient are not all positive.'));
                                    break;
                                end
                            end
                        end
                        if ~valid, break; end
                    end
                else
                    for i = 1:n,
                        for j = 1:n,
                            if (j ~= i)
                                x0 = lb;
                                if (lb(1,j) == 0)
                                    x0 = ub;
                                end
                                fmincon_err = 0;
                                try
                                    [T, ~, fval, ~, output] = evalc('fmincon(@(x) func_ij(handle_nabla_G,x,i,j), x0, [], [], [], [], lb, ub, [], options)');
                                catch exception
                                    fmincon_err = 1;
                                end

                                if ~fmincon_err, fmincon_err = ~sol_found(T); end
                                if fmincon_err
                                    fmincon_err = 0;
                                    try
                                        [T, ~, fval, ~, output] = evalc('fmincon(@(x) func_ij(handle_nabla_G,x,i,j), x0, [], [], [], [], lb, ub, [], alt_options)');
                                    catch exception
                                        fmincon_err = 1;
                                    end
                                end

                                if ~fmincon_err, fmincon_err = ~sol_found(T); end
                                if ~fmincon_err
                                    if output.iterations ~= 0
                                        fmin_itr = fmin_itr + output.iterations;
                                    else
                                        fmin_itr = fmin_itr + 1;
                                    end
                                    func_count = func_count + output.funcCount;
                                    if (fval < 0)
                                        valid = 0;
                                        msg = strcat(msg,sprintf('\n    -The off-diagonal elements of the constraint gradient are not all positive.'));
                                        break;
                                    end
                                else
                                    error = 1;
                                    valid = 0;
                                    msg = 'Error: fmincon caught internal exception. The problem cannot be verified.';
                                    break;
                                end
                            end
                        end
                        if ~valid, break, end
                    end
                end
            end

            if (valid)
                msg = strcat(msg,sprintf('\n    -The off-diagonal elements of the constraint gradient are all positive.'));

                if adv && data_adv.constr_grad
                    f_min = feval(handle_nabla_G,lb);
                    f_max = feval(handle_nabla_G,ub);
                    for i = 1:n,
                        tot_itr = tot_itr + 1;
                        sum_min = ones(1,n)*abs(f_min(:,i));
                        sum_max = ones(1,n)*abs(f_max(:,i));

                        if (2*f_min(i,i) <= sum_min || 2*f_max(i,i) <= sum_max)
                            valid = 0;
                            checked3c = 1;
                            msg = strcat(msg,sprintf('\n    -The diagonal elements are not all larger than the absolute sum of the same column.'));
                            break;
                        end
                    end
                else
                    c = 1;
                    for i = 1:n,
                        x0 = lb;
                        if (lb(1,i) == 0)
                            x0 = ub;
                        end
                        fmincon_err = 0;
                        try
                            [T, ~, fval, ~, output] = evalc('fmincon(@(x) diagonal2_nabla_G(handle_nabla_G,x,i,n,c), x0, [], [], [], [], lb, ub, [], options)');
                        catch exception
                            fmincon_err = 1;
                        end

                        if ~fmincon_err, fmincon_err = ~sol_found(T); end
                        if fmincon_err
                            fmincon_err = 0;
                            try
                                [T, ~, fval, ~, output] = evalc('fmincon(@(x) diagonal2_nabla_G(handle_nabla_G,x,i,n,c), x0, [], [], [], [], lb, ub, [], alt_options)');
                            catch exception
                                fmincon_err = 1;
                            end
                        end

                        if ~fmincon_err, fmincon_err = ~sol_found(T); end
                        if ~fmincon_err
                            if output.iterations ~= 0
                                fmin_itr = fmin_itr + output.iterations;
                            else
                                fmin_itr = fmin_itr + 1;
                            end
                            func_count = func_count + output.funcCount;
                            if (fval <= 0)
                                valid = 0;
                                checked3c = 1;
                                msg = strcat(msg,sprintf('\n    -The diagonal elements are not all larger than the absolute sum of the same column.'));
                                break;
                            end
                        else
                            error = 1;
                            valid = 0;
                            msg = 'Error: fmincon caught internal exception. The problem cannot be verified.';
                            break;
                        end
                    end
                end

                if (valid)
                    f_lip = 1;
                    msg = strcat(msg,sprintf('\n    -The diagonal elements are all larger than the absolute sum of the same column.'));
                end
            end
        end

        % Check if the objective is one-dimensional and if condition (3.8h)
        % hold
        if (~error && ~f_lip && m == 1)
            msg = strcat(msg,sprintf('\n3. -The objective function is scalar.'));
            if ~checked3c
                if custom
                    if adv && data_adv.obj_grad && delta_s == -1
                        f_min = -feval(handle_nabla_g_0,lb);
                        f_max = -feval(handle_nabla_g_0,ub);
                        min = Inf;
                        max = 0;
                        for i = 1:m,
                            for j = 1:n,
                                tot_itr = tot_itr + 1;
                                if min > f_min(i,j); min = f_min(i,j); end
                                if min > f_max(i,j); min = f_max(i,j); end
                                if max < f_min(i,j); max = f_min(i,j); end
                                if max < f_max(i,j); max = f_max(i,j); end

                            end
                        end
                        delta_s = min;
                        delta_l = max;
                    else
                        if delta_l == -1
                            [delta_l,itrs,funcs] = delta_large(@(x) -handle_nabla_g_0(x), lb, ub);
                            fmin_itr = fmin_itr + itrs;
                            func_count = func_count + funcs;
                        end
                        if delta_s == -1
                            [delta_s,itrs,funcs] = delta_small(@(x) -handle_nabla_g_0(x), lb, ub);
                            fmin_itr = fmin_itr + itrs;
                            func_count = func_count + funcs;
                        end
                    end
                else
                    [delta_s,delta_l] = delta_suggested(1,lb,ub,obj_data);
                end

                c = delta_s/(delta_s + delta_l);
                valid = 1;

                if adv && data_adv.constr_grad
                    f_min = feval(handle_nabla_G,lb);
                    f_max = feval(handle_nabla_G,ub);
                    for i = 1:n,
                        tot_itr = tot_itr + 1;
                        sum_min = ones(1,n)*abs(f_min(:,i));
                        sum_max = ones(1,n)*abs(f_max(:,i));

                        if ((c+1)*f_min(i,i) <= sum_min || (c+1)*f_max(i,i) <= sum_max)
                            valid = 0;
                            msg = strcat(msg,sprintf...
                                ('\n    -The diagonal elements are not all larger than the absolute sum of the same column with coefficient %.3f.',c));
                            break;
                        end
                    end
                else
                    for i = 1:n,
                        x0 = lb;
                        if (lb(1,i) == 0)
                            x0 = ub;
                        end
                        fmincon_err = 0;
                        try
                            [T, ~, fval, ~, output] = evalc('fmincon(@(x) diagonal2_nabla_G(handle_nabla_G,x,i,n,c), x0, [], [], [], [], lb, ub, [], options)');
                        catch exception
                            fmincon_err = 1;
                        end

                        if ~fmincon_err, fmincon_err = ~sol_found(T); end
                        if fmincon_err
                            fmincon_err = 0;
                            try
                                [T, ~, fval, ~, output] = evalc('fmincon(@(x) diagonal2_nabla_G(handle_nabla_G,x,i,n,c), x0, [], [], [], [], lb, ub, [], alt_options)');
                            catch exception
                                fmincon_err = 1;
                            end
                        end

                        if ~fmincon_err, fmincon_err = ~sol_found(T); end
                        if ~fmincon_err
                            if output.iterations ~= 0
                                fmin_itr = fmin_itr + output.iterations;
                            else
                                fmin_itr = fmin_itr + 1;
                            end
                            func_count = func_count + output.funcCount;
                            if (fval <= 0)
                                valid = 0;
                                msg = strcat(msg,sprintf...
                                    ('\n    -The diagonal elements are not all larger than the absolute sum of the same column with coefficient %.3f.',c));
                                break;
                            end
                        else
                            valid = 0;
                            msg = 'Error: fmincon caught internal exception. The problem cannot be verified.';
                            break;
                        end
                    end
                end
            else
                valid = 0;
                msg = strcat(msg,sprintf...
                    ('\n    -The diagonal elements are not all larger than the absolute sum of the same column with some coefficient < 1.'));
            end

            if (valid)
                f_lip = 1;
                msg = strcat(msg,sprintf...
                    ('\n    -The diagonal elements are all larger than the absolute sum of the same column with coefficient %.3f.',c));
            end
        end


        if (~f_lip)
            msg1 = sprintf...
                ('\n\nThe problem is not F-Lipschitz.\nUnconstrained fmincon used %i iterations and %i function evaluations in total.',fmin_itr,func_count);
            msg = strcat...
                (msg,msg1,sprintf('\nTotal amount of iterations: %i',fmin_itr+tot_itr));
        else
            msg1 = sprintf...
                ('\n\nThe problem is F-Lipschitz.\nUnconstrained fmincon used %i iterations and %i function evaluations in total.',fmin_itr,func_count);
            msg = strcat...
                (msg,msg1,sprintf('\nTotal amount of iterations: %i',fmin_itr+tot_itr));
        end

        tot_itr = tot_itr + fmin_itr;
        catch exception
            msg = exception.message;
        end
    else
        msg = 'Error: Too few input arguments.';
    end
end