function [f_lip,msg,tot_itr,func_count] = isflipquadcon(handle_nabla_f_0,m,n,Q,r,lb,ub,data_adv,obj_data)
    inputerr = 0;
    if nargin == 9
        adv = 1;
        custom = 0;
    elseif nargin == 8
        adv = 1;
        custom = 1;
    elseif nargin < 7
        inputerr = 1;
    else
        adv = 0;
        custom = 1;
    end
    
    f_lip = 0;
    error = 0;
    tot_itr = 0;
    fmin_itr = 0;
    func_count = 0;
    
    if ~inputerr
        checked3c = 0;
        delta_s = -1;
        delta_l = -1;

        min_bound = zeros(n,n,n);
        max_bound = zeros(n,n,n);

        options = optimset('Algorithm','active-set');
        alt_options = optimset('Algorithm','interior-point');

        try
        % Check if objective function is strictly increasing
        if custom
            if adv && data_adv.obj_strict
                xm = lb + (ub - lb)./2;
                val = feval(handle_nabla_f_0,xm);
                if isnan(val(1,1))
                    error = 1;
                    msg = 'Error: the objective gradient is not defined everywhere.';
                elseif val(1,1) < 0
                    error = 1;
                    msg = '-The objective function is not strictly increasing.';
                elseif val == 0
                    error = 1;
                    msg = 'Error: Incorrect information, the objective function is not strictly increasing.';
                end
            elseif adv && data_adv.obj_grad
                f_min = feval(handle_nabla_f_0,lb);
                f_max = feval(handle_nabla_f_0,ub);
                min = Inf;
                max = 0;
                for i = 1:m,
                    for j = 1:n,
                        tot_itr = tot_itr + 1;
                        if min > f_min(i,j); min = f_min(i,j); end
                        if min > f_max(i,j); min = f_max(i,j); end
                        if max < f_min(i,j); max = f_min(i,j); end
                        if max < f_max(i,j); max = f_max(i,j); end

                        if isnan(f_min(i,j)) || isnan(f_max(i,j))
                            error = 1;
                            msg = 'Error: the objective gradient is not defined everywhere.';
                            break;
                        elseif f_min(i,j) <= 0 || f_max(i,j) <= 0
                            error = 1;
                            msg = '-The objective function is not strictly increasing.';
                            break;
                        end
                    end
                    if error, break; end
                end
                delta_s = min;
                delta_l = max;
            else
                min = Inf;
                for i = 1:m,
                    for j = 1:n,
                        x0 = lb;
                        if (lb(1,j) == 0)
                            x0 = ub;
                        end
                        fmincon_err = 0;
                        try
                            [T, ~, fval, ~, output] = evalc('fmincon(@(x) func_ij(handle_nabla_f_0,x,i,j), x0, [], [], [], [], lb, ub, [], options)');
                        catch exception
                            fmincon_err = 1;
                        end

                        if ~fmincon_err, fmincon_err = ~sol_found(T); end
                        if fmincon_err
                            fmincon_err = 0;
                            try
                                [T, ~, fval, ~, output] = evalc('fmincon(@(x) func_ij(handle_nabla_f_0,x,i,j), x0, [], [], [], [], lb, ub, [], alt_options)');
                            catch exception
                                fmincon_err = 1;
                            end
                        end

                        if ~fmincon_err, fmincon_err = ~sol_found(T); end
                        if ~fmincon_err
                            if output.iterations ~= 0
                                fmin_itr = fmin_itr + output.iterations;
                            else
                                fmin_itr = fmin_itr + 1;
                            end
                            func_count = func_count + output.funcCount;
                            if (m == 1 && fval < min), min = fval; end
                            if (fval <= 0)
                                error = 1;
                                msg = '-The objective function is not strictly increasing.';
                                break;
                            end
                        else
                            error = 1;
                            msg = 'Error: fmincon caught internal exception. The problem cannot be verified.';
                            break;
                        end
                    end
                    if (error), break; end
                end
                delta_s = min;
            end
        else
            % Check if the bounds fulfill potential requirements
            if ~isempty(obj_data.neg_idx)
                for i = 1:length(obj_data.neg_idx),
                    if ub(obj_data.neg_idx(i)) >= 0
                        error = 1;
                        msg1 = 'Error: In order to have a strictly increasing objective function, the following terms of x must be bounded to only negative numbers:';
                        msg2 = idx2str(obj_data.neg_idx);
                        msg = strcat(msg1,msg2);
                        break;
                    end
                end
            elseif ~isempty(obj_data.pos_idx)
                for i = 1:length(obj_data.pos_idx),
                    if lb(obj_data.pos_idx(i)) <= 0
                        error = 1;
                        msg1 = 'Error: In order to have a strictly increasing objective function, the following terms of x must be bounded to only positive numbers:';
                        msg2 = idx2str(obj_data.pos_idx);
                        msg = strcat(msg1,msg2);
                        break;
                    end
                end
            end
        end


        % Check the infinity norm
        if (~error)
            msg = sprintf('-The objective function is strictly increasing.');
            if adv && (data_adv.constr_grad || data_adv.constr)
                for i = 1:n,
                    tot_itr = tot_itr + 1;
                    Q_gr = Q(:,:,i) + Q(:,:,i)';
                    inf_min = ones(1,n)*abs(Q_gr*lb' + r(i,:)');
                    inf_max = ones(1,n)*abs(Q_gr*ub' + r(i,:)');

                    if isnan(inf_min) || isnan(inf_max)
                        error = 1;
                        msg = 'Error: The constraint gradient is not defined everywhere.';
                        break;
                    elseif inf_min >= 1 || inf_max >= 1
                        error = 1;
                        msg1 = sprintf('\n-The infinity norm is not less than one.');
                        msg = strcat(msg,msg1);
                        break;
                    end
                end
            else
                for i = 1:n,
                    x_neg = zeros(1,n);
                    x_pos = zeros(1,n);
                    Q_gr = Q(:,:,i) + Q(:,:,i)';
                    for j = 1:n,
                        tot_itr = tot_itr + 1;
                        sum_column = ones(1,n)*Q_gr(:,j);
                        if sum_column >= 0
                            x_neg(j) = lb(j);
                            x_pos(j) = ub(j);
                        else
                            x_neg(j) = ub(j);
                            x_pos(j) = lb(j);
                        end
                    end
                    inf_min = ones(1,n)*abs(Q_gr*x_neg' + r(i,:)');
                    inf_max = ones(1,n)*abs(Q_gr*x_pos' + r(i,:)');

                    if inf_min >= 1 || inf_max >= 1
                        error = 1;
                        msg1 = sprintf('\n-The infinity norm is not less than one.');
                        msg = strcat(msg,msg1);
                        break;
                    end
                end
            end
        end

        % Check if all elements are positive
        if (~error)
            msg1 = sprintf('\n-The infinity norm is less than one.');
            msg = strcat(msg,msg1,sprintf('\n\nAlternatives:'));
            valid = 1;

            if adv && data_adv.constr
                xm = lb + (ub - lb)./2;
                Q_gr = Q(:,:,1) + Q(:,:,1)';
                val = Q_gr(1,:)*xm' + r(1,1);
                if val < 0
                    valid = 0;
                    msg = strcat(msg,sprintf('\n1. -The elements of the constraint gradient are not all positive.'));
                end
            elseif adv && data_adv.constr_grad
                for i = 1:n,
                    for j = 1:n,             
                        tot_itr = tot_itr + 1;
                        Q_gr = Q(:,:,1) + Q(:,:,1)';
                        lower_val = Q_gr(j,:)*lb' + r(i,j);
                        upper_val = Q_gr(j,:)*ub' + r(i,j);

                        if (lower_val < 0 || upper_val < 0)
                            valid = 0;
                            msg = strcat(msg,sprintf('\n1. -The elements of the constraint gradient are not all positive.'));
                            break;
                        end
                    end
                end
            else
                for i = 1:n,
                    for j = 1:n,
                        sum_min = 0;
                        sum_max = 0;
                        for h = 1:n,
                            tot_itr = tot_itr + 1;
                            a = Q(h,j,i) + Q(j,h,i);
                            if a > 0
                                if valid, sum_min = sum_min + a*lb(h); end
                                if valid, sum_max = sum_max + a*ub(h); end
                                min_bound(j,h,i) = lb(h);
                                max_bound(j,h,i) = ub(h);
                            elseif a < 0
                                if valid, sum_min = sum_min + a*ub(h); end
                                if valid, sum_max = sum_max + a*lb(h); end
                                min_bound(j,h,i) = ub(h);
                                max_bound(j,h,i) = lb(h);
                            end
                        end

                        if valid, lower_val = sum_min + r(i,j); end
                        if valid, upper_val = sum_max + r(i,j); end
                        if valid && (lower_val < 0 || upper_val < 0)
                            valid = 0;
                            msg = strcat(msg,sprintf('\n1. -The elements of the constraint gradient are not all positive.'));
                        end
                    end
                end
            end

            if (valid)
                f_lip = 1;
                msg = strcat(msg,sprintf('\n1. -The elements of the constraint gradient are all positive.'));
            end
        end

        % Check if nabla_j_f_0 = nabla_i_f_0 and if all elements
        % are negative.
        if (~error && ~f_lip && m == 1)
            valid = 1;
            if custom
                eval = zeros(1,6);
                eval_comp = zeros(1,6);
                for i = 1:6,
                    vals = lb + ((ub-lb)/5).*(i-1);
                    eval(i) = func_ij(handle_nabla_f_0,vals,1,1);
                end
                if eval*ones(6,1) == eval(1)*6;
                    for i = 2:n,
                        tot_itr = tot_itr + 1;
                        for j = 1:6,
                            vals = lb + ((ub-lb)/5).*(i-1);
                            eval_comp(j) = func_ij(handle_nabla_f_0,vals,1,i);
                        end
                        if ~isequal(eval,eval_comp)
                            valid = 0;
                            msg = strcat(msg,sprintf('\n2. -The gradients of the objective are not equal.'));
                            break;
                        end
                    end
                else
                    valid = 0;
                    msg = strcat(msg,sprintf('\n2. -The gradients of the objective are not equal.'));
                end
            else
                valid = (obj_data.func_type == 1) && obj_data.uniform;
                if ~valid, msg = strcat(msg,sprintf('\n2. -The gradients of the objective are not equal.')); end
            end

            if (valid)
                msg = strcat(msg,sprintf('\n2. -The gradients of the objective are equal.'));

                if adv && data_adv.constr
                    xm = lb + (ub - lb)./2;
                    Q_gr = Q(:,:,1) + Q(:,:,1)';
                    val = Q_gr(1,:)*xm' + r(1,1);
                    if val > 0
                        valid = 0;
                        msg = strcat(msg,sprintf('\n    -The elements of the constraint gradient are not all negative.'));
                    end
                elseif adv && data_adv.constr_grad
                    for i = 1:n,
                        for j = 1:n,       
                            tot_itr = tot_itr + 1;
                            Q_gr = Q(:,:,1) + Q(:,:,1)';
                            lower_val = Q_gr(j,:)*lb' + r(i,j);
                            upper_val = Q_gr(j,:)*ub' + r(i,j);

                            if (lower_val > 0 || upper_val > 0)
                                valid = 0;
                                msg = strcat(msg,sprintf('\n    -The elements of the constraint gradient are not all negative.'));
                            end
                        end
                    end
                else
                    for i = 1:n,
                        for j = 1:n,
                            tot_itr = tot_itr + 1;
                            lower_val = Q_gr(j,:)*min_bound(j,:,i)' + r(i,j);
                            upper_val = Q_gr(j,:)*max_bound(j,:,i)' + r(i,j);
                            if lower_val > 0 || upper_val > 0
                                valid = 0;
                                msg = strcat(msg,sprintf('\n    -The elements of the constraint gradient are not all negative.'));
                                break;
                            end
                        end
                        if ~valid, break, end
                    end
                end
            end

            if (valid)
                msg = strcat(msg,sprintf('\n    -The elements of the constraint gradient are all negative.'));
                if adv && (data_adv.constr_grad || data_adv.constr)
                    for i = 1:n,
                        Q_gr_ = zeros(n,n);
                        for j = 1:n,
                            tot_itr = tot_itr + 1;
                            Q_gr = Q(:,:,j) + Q(:,:,j)';
                            Q_gr_(j,:) = Q_gr(i,:);
                        end

                        one_min = ones(1,n)*abs(Q_gr_*lb' + r(:,i));
                        one_max = ones(1,n)*abs(Q_gr_*ub' + r(:,i));

                        if (one_min >= 1 || one_max >= 1)
                            valid = 0;
                            checked3c = 1;
                            msg = strcat(msg,sprintf('\n    -The one norm of the constraint gradient is not smaller than one'));
                            break;
                        end
                    end
                else
                    for i = 1:n,
                        Q_gr_ = zeros(n,n);
                        x_neg = zero(1,n);
                        x_pos = zero(1,n);
                        for j = 1:n,
                            tot_itr = tot_itr + 1;
                            Q_gr = Q(:,:,j) + Q(:,:,j)';
                            Q_gr_(j,:) = Q_gr(i,:);
                        end
                        for j = 1:n,
                            tot_itr = tot_itr + 1;
                            sum_column = ones(1,n)*Q_gr_(:,j);
                            if sum_column >= 0
                                x_neg(1,j) = lb(1,j);
                                x_pos(1,j) = ub(1,j);
                            else
                                x_neg(1,j) = ub(1,j);
                                x_pos(1,j) = lb(1,j);
                            end
                        end

                        one_min = ones(1,n)*abs(Q_gr_*x_neg' + r(:,i));
                        one_max = ones(1,n)*abs(Q_gr_*x_pos' + r(:,i));

                        if (one_min >= 1 || one_max >= 1)
                            valid = 0;
                            checked3c = 1;
                            msg = strcat(msg,sprintf('\n    -The one norm of the constraint gradient is not smaller than one'));
                            break;
                        end
                    end
                end

                if (valid)
                    f_lip = 1;
                    msg = strcat(msg,sprintf('\n    -The one norm of the constraint gradient is smaller than one.'));
                end
            end
        end

        % Check if the objective is one-dimensional and if condition (3.2h)
        % hold
        if (~error && ~f_lip && m == 1)
            msg = strcat(msg,sprintf('\n3. -The objective function is scalar.'));
            if ~checked3c
                if custom
                    if adv && data_adv.obj_grad && delta_s == -1
                        f_min = feval(handle_nabla_f_0,lb);
                        f_max = feval(handle_nabla_f_0,ub);
                        min = Inf;
                        max = 0;
                        for i = 1:m,
                            for j = 1:n,
                                tot_itr = tot_itr + 1;
                                if min > f_min(i,j); min = f_min(i,j); end
                                if min > f_max(i,j); min = f_max(i,j); end
                                if max < f_min(i,j); max = f_min(i,j); end
                                if max < f_max(i,j); max = f_max(i,j); end

                            end
                        end
                        delta_s = min;
                        delta_l = max;
                    else
                        if delta_l == -1
                            [delta_l,itrs,funcs] = delta_large(@(x) handle_nabla_f_0(x), lb, ub);
                            fmin_itr = fmin_itr + itrs;
                            func_count = func_count + funcs;
                        end
                        if delta_s == -1
                            [delta_s,itrs,funcs] = delta_small(@(x) handle_nabla_f_0(x), lb, ub);
                            fmin_itr = fmin_itr + itrs;
                            func_count = func_count + funcs;
                        end
                    end
                else
                    [delta_s,delta_l] = delta_suggested(1,lb,ub,obj_data);
                end

                c = delta_s/(delta_s + delta_l);
                valid = 1;

                if adv && (data_adv.constr_grad || data_adv.constr)
                    for i = 1:n,
                        Q_gr_ = zeros(n,n);
                        for j = 1:n,
                            tot_itr = tot_itr + 1;
                            Q_gr = Q(:,:,j) + Q(:,:,j)';
                            Q_gr_(j,:) = Q_gr(i,:);
                        end

                        one_min = ones(1,n)*abs(Q_gr_*lb' + r(:,i));
                        one_max = ones(1,n)*abs(Q_gr_*ub' + r(:,i));

                        if (one_min >= c || one_max >= c)
                            valid = 0;
                            msg = strcat(msg,sprintf...
                            ('\n    -The one norm of the constraint gradient is not smaller than the coefficient %.3f.',c));
                            break;
                        end
                    end
                else
                    for i = 1:n,
                        Q_gr_ = zeros(n,n);
                        x_neg = zeros(1,n);
                        x_pos = zeros(1,n);
                        for j = 1:n,
                            tot_itr = tot_itr + 1;
                            Q_gr = Q(:,:,j) + Q(:,:,j)';
                            Q_gr_(j,:) = Q_gr(i,:);
                        end
                        for j = 1:n,
                            tot_itr = tot_itr + 1;
                            sum_column = ones(1,n)*Q_gr_(:,j);
                            if sum_column >= 0
                                x_neg(1,j) = lb(1,j);
                                x_pos(1,j) = ub(1,j);
                            else
                                x_neg(1,j) = ub(1,j);
                                x_pos(1,j) = lb(1,j);
                            end
                        end

                        one_min = ones(1,n)*abs(Q_gr_*x_neg' + r(:,i));
                        one_max = ones(1,n)*abs(Q_gr_*x_pos' + r(:,i));

                        if one_min >= c || one_max >= c
                            valid = 0;
                            msg = strcat(msg,sprintf...
                            ('\n    -The one norm of the constraint gradient is not smaller than the coefficient %.3f.',c));
                            break;
                        end
                    end
                end
            else
                valid = 0;
                msg = strcat(msg,sprintf...
                ('\n    -The one norm of the constraint gradient is not smaller than some coefficient < 1.'));
            end

            if (valid)
                f_lip = 1;
                msg = strcat(msg,sprintf...
                    ('\n    -The one norm of the constraint gradient is smaller than the coefficient %.3f.',c));
            end
        end

        if (~f_lip)
            msg1 = sprintf...
                ('\n\nThe problem is not F-Lipschitz.\nUnconstrained fmincon used %i iterations and %i function evaluations in total.',fmin_itr,func_count);
            msg = strcat...
                (msg,msg1,sprintf('\nTotal amount of iterations: %i',fmin_itr+tot_itr));
        else
            msg1 = sprintf...
                ('\n\nThe problem is F-Lipschitz.\nUnconstrained fmincon used %i iterations and %i function evaluations in total.',fmin_itr,func_count);
            msg = strcat...
                (msg,msg1,sprintf('\nTotal amount of iterations: %i',fmin_itr+tot_itr));
        end

        tot_itr = tot_itr + fmin_itr;
        catch exception
            msg = exception.message;
        end
    else
        msg = 'Error: Too few input arguments.';
    end
end