function [error,error_msg,var] = test_vector_input(input,matrix,name)
    error = 0;
    error_msg = '';
    var = 0;
    A_error = sprintf('Error: The matrix %s must either be given on matrix/vector form, [a b; c d], or as a variable which is in the workspace.',name);
    v_error = sprintf('Error: The vector %s must either be given on vector form, [a b c], or as a variable which is in the workspace.',name);
    if (~isempty(input) && input(1) == '[' && input(length(input)) == ']')
        var_string = input(2:length(input)-1);
        if (isempty(var_string))
            error = 1;
            if matrix, error_msg = A_error; else error_msg = v_error; end
        else
            split_string = regexp(var_string, '\;', 'split');
            if (~matrix && length(split_string) ~= 1)
                error = 1;
                error_msg = v_error;
            else
                letters = regexpi(var_string, '[A-Z]');
                if (~isempty(letters))
                    error = 1;
                    error_msg = 'Error: The matrix or vector definition can only contain numbers and Inf is not allowed.';
                else
                    msg = sprintf('Error: The dimensions of matrix %s are incorrect.',name);
                    m = length(split_string);
                    first_row = sscanf(regexprep(char(split_string(1)),',',' '),'%f');
                    n = length(first_row);
                    matr = zeros(m,n);
                    if n >= m
                        matr(1,1:n) = first_row; 
                    else
                        error = 1;
                        error_msg = msg;
                    end
                    
                    for i = 2:m,
                        row = sscanf(regexprep(char(split_string(i)),',',' '),'%f');
                        if (length(row) == n)
                            matr(i,1:n) = row;
                        else
                            error = 1;
                            error_msg = msg;
                            break;
                        end
                    end
                    var = matr;
                end
            end
        end
    else
        try
            var = evalin('base',input);
        catch exception,
            error = 1;
            if matrix, error_msg = A_error; else error_msg = v_error; end
        end
        if (~error && ~isa(var,'double'))
            error = 1;
            error_msg = sprintf('Error: %s is not a matrix or vector.', input);
        end
        if (~error && ~matrix)
            [rows,cols] = size(var);
            if rows ~= 1 && cols ~= 1
                error = 1;
                error_msg = sprintf('Error: %s is a matrix, %s should be a vector.', input, name);
            end
        end
    end
    if (~matrix)
        [rows,~] = size(var);
        if (rows ~= 1)
            var = var';
        end
    end
end